import logging
import os

from grid5000 import Grid5000

import pandas as pd
import matplotlib.pyplot as plt
import seaborn as sns
import time

logging.basicConfig(level=logging.DEBUG)

conf_file = os.path.join(os.environ.get("HOME"), ".python-grid5000.yaml")
gk = Grid5000.from_yaml(conf_file)

metrics = gk.sites["lyon"].metrics
print("--- available metrics")
print(metrics.list())

print("---- power metric")
print(metrics["power"])

print("----- a timeserie")
now = time.time()
kwargs = {
    "only": "nova-1,nova-2,nova-3",
    "resolution": 1,
    "from": int(now - 600),
    "to": int(now)
}
timeseries = metrics["power"].timeseries.list(**kwargs)

# let's visualize this
df = pd.DataFrame()
for timeserie in timeseries:
    print(timeserie)
    timestamp = timeserie.timestamps
    value = timeserie.values
    measurement = timeserie.uid
    df = pd.concat([df, pd.DataFrame({
        "timestamp": timestamp,
        "value": value,
        "measurement": [measurement]*len(timestamp)
    })])

sns.relplot(data=df,
            x="timestamp",
            y="value",
            hue="measurement",
            kind="line")
plt.show()
